Authors
=======

- Aleksey Kladov
- Brian Dixon
- Corey Bertram
- Damien Nozay
- Daniel Levy
- Daniel Roschka
- George Vilches
- Hamish Downer
- jofusa
- Joao Pedro Francese
- Jonathan Sanchez
- Josh Fyne
- Klaas van Schelven
- macro1
- Marty Alchin
- Mauricio de Abreu Antunes
- Rajesh Pappula
- Trey Hunner
- Ulysses Vilela
- vnagendra

Background
==========

This code originally comes from Pro Django, published by Apress, Inc.
in December 2008. The author of the book and primary author
of the code is Marty Alchin <marty@martyalchin.com>, who
may be found online at <http://martyalchin.com/>.

As part of the technical review process, additional code
modifications were provided by the technical reviewer,
George Vilches <gav@thataddress.com>.

This code was originally extended, licensed, and improved by
Corey Bertram <corey@qr7.com> with the permission of Marty Alchin.
